@@ -1,5 +1,6 @@
 /*
 Copyright (C) 2005 Matthias Braun <matze@braunis.de>
+Copyright (C) 2024 David Bears <dbear4q@gmail.com>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -78,7 +79,10 @@ Event::Event(SDL_Event& event)
 
 Event::Event(float _elapsedTime)
     : type(UPDATE), inside(false), elapsedTime(_elapsedTime)
-{
-}
+{}
+
+Event::Event(Type type)
+    : type(type)
+{}
 
 /** @file gui/Event.cpp */
