@@ -1,24 +1,41 @@
 /* ---------------------------------------------------------------------- *
- * lintypes.c
- * This file is part of lincity.
- * Lincity is copyright (c) I J Peters 1995-1997, (c) Greg Sharp 1997-2001.
- * ---------------------------------------------------------------------- */
+ * src/lincity/lintypes.cpp
+ * This file is part of Lincity-NG.
+ *
+ * Copyright (C) 1995-1997 I J Peters
+ * Copyright (C) 1997-2005 Greg Sharp
+ * Copyright (C) 2000-2004 Corey Keasling
+ * Copyright (C) 2022-2024 David Bears <dbear4q@gmail.com>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+** ---------------------------------------------------------------------- */
 
 #include "lintypes.h"
 
 #include <assert.h>                 // for assert
 #include <stdlib.h>                 // for rand
-#include <algorithm>                // for copy, max
 #include <iostream>                 // for basic_ostream, operator<<, basic_...
 #include <sstream>                  // for basic_istringstream
 #include <utility>                  // for pair
 #include <vector>                   // for vector
 
-#include "commodities.hpp"
 #include "ConstructionCount.h"      // for ConstructionCount
 #include "ConstructionManager.h"    // for ConstructionManager
 #include "ConstructionRequest.h"    // for ConstructionDeletionRequest, Powe...
-#include "Vehicles.h"               // for VehicleStrategy, COMMUTER_TRAFFIC...
+#include "Vehicles.h"               // for Vehicle, VehicleStrategy, COMMUTE...
+#include "commodities.hpp"          // for CommodityRule, Commodity, operator++
 #include "engglobs.h"               // for world, binary_mode, total_money
 #include "groups.h"                 // for GROUP_POWER_LINE, GROUP_FIRE, GRO...
 #include "gui_interface/mps.h"      // for mps_store_ssddp, mps_store_title
@@ -33,7 +50,7 @@
 #include "world.h"                  // for World, MapTile
 #include "xmlloadsave.h"            // for XMLTemplate, bin_template_libary
 
-extern int lincitySpeed; // is defined in lincity-ng/MainLincity.cpp
+extern int simDelay; // is defined in lincity-ng/MainLincity.cpp
 
 
 //Construction Declarations
@@ -969,13 +986,13 @@ void Construction::trade()
         if(transport) //Special for transport
         {
             transport->trafficCount[stuff_ID] = (9 * transport->trafficCount[stuff_ID] + max_traffic) / 10;
-            if(lincitySpeed != fast_time_for_year
+            if(simDelay != SIM_DELAY_FAST
             && getConfig()->carsEnabled
             && 100 * max_traffic *  TRANSPORT_RATE / TRANSPORT_QUANTA > 2
             && world(x,y)->getTransportGroup() == GROUP_ROAD)
             {
                 int yield = 50 * max_traffic *  TRANSPORT_RATE / TRANSPORT_QUANTA;
-                if(lincitySpeed == MED_TIME_FOR_YEAR) // compensate for overall animation
+                if(simDelay == SIM_DELAY_MED) // compensate for overall animation
                 {   yield = (yield+1)/2;}
                 switch (stuff_ID)
                 {
