@@ -1,9 +1,32 @@
+/* ---------------------------------------------------------------------- *
+ * src/lincity/xmlloadsave.cpp
+ * This file is part of Lincity-NG.
+ *
+ * Copyright (C) 1995-1997 I J Peters
+ * Copyright (C) 1997-2005 Greg Sharp
+ * Copyright (C) 2000-2004 Corey Keasling
+ * Copyright (C) 2022-2024 David Bears <dbear4q@gmail.com>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+** ---------------------------------------------------------------------- */
+
 #include "xmlloadsave.h"
 
 #include <assert.h>                        // for assert
 #include <stdio.h>                         // for sscanf
 #include <string.h>                        // for strcpy
-#include <algorithm>                       // for max
 #include <array>                           // for array
 #include <iostream>                        // for cout
 #include <set>                             // for set
@@ -221,6 +244,8 @@ int XMLloadsave::saveXMLfile(std::string xml_file_name)
     }
     std::cout << "gz saving " << xml_file_name << " ... ";
     std::cout.flush();
+    binary_mode = false; // just to make sure
+    seed_compression = false; // just to make sure
     clearXMLlibary();
     xml_file_out.str("");
     ldsv_version = XML_LOADSAVE_VERSION;
